@@ -33,8 +33,8 @@ public:
 
     virtual AbstractAccountParametersWidget
               *mainOptionsWidget(ParameterEditModel *model,
-                                 QWidget *parent = 0) const;
-    virtual bool hasAdvancedOptionsWidget() const;
+                                 QWidget *parent = 0) const override;
+    virtual bool hasAdvancedOptionsWidget() const override;
 
 private:
     Q_DISABLE_COPY(HazeSkypeWebAccountUi)
