@@ -33,11 +33,11 @@ public:
 
     virtual AbstractAccountParametersWidget
               *mainOptionsWidget(ParameterEditModel *model,
-                                 QWidget *parent = 0) const;
-    virtual bool hasAdvancedOptionsWidget() const;
+                                 QWidget *parent = 0) const override;
+    virtual bool hasAdvancedOptionsWidget() const override;
     virtual AbstractAccountParametersWidget
               *advancedOptionsWidget(ParameterEditModel *model,
-                                     QWidget *parent = 0) const;
+                                     QWidget *parent = 0) const override;
 private:
     Q_DISABLE_COPY(IdleAccountUi)
 };
