@@ -31,9 +31,9 @@ public:
     explicit SipeAccountUi(QObject *parent = 0);
     virtual ~SipeAccountUi();
 
-    virtual AbstractAccountParametersWidget* mainOptionsWidget(ParameterEditModel *model, QWidget *parent = 0) const;
-    virtual bool hasAdvancedOptionsWidget() const;
-    virtual AbstractAccountParametersWidget* advancedOptionsWidget(ParameterEditModel *model, QWidget *parent = 0) const;
+    virtual AbstractAccountParametersWidget* mainOptionsWidget(ParameterEditModel *model, QWidget *parent = 0) const override;
+    virtual bool hasAdvancedOptionsWidget() const override;
+    virtual AbstractAccountParametersWidget* advancedOptionsWidget(ParameterEditModel *model, QWidget *parent = 0) const override;
 
 private:
     Q_DISABLE_COPY(SipeAccountUi)
